@@ -3,21 +3,22 @@
 #define HOST_VENDOR "pc"
 #define HOST_OS "linux"
 #define HOST_OS_NAME "linux"
-#define HOST_OS_VERSION "2.2.19-2cucs"
+#define HOST_OS_VERSION "2.2.18"
 #define HOST_ARCH "i386"
-#define HOST_NAME "earth.cs.columbia.edu"
+#define HOST_NAME "whitestar.dyn.optonline.net"
 #define USER_NAME "ezk"
-#define CONFIG_DATE "Tue Jul  3 20:36:13 EDT 2001"
+#define CONFIG_DATE "Sat Apr 14 17:21:23 EDT 2001"
 #define PACKAGE "am-utils"
-#define VERSION "6.0.8s1"
+#define VERSION "6.0.6s2"
 #define PACKAGE "am-utils"
-#define VERSION "6.0.8s1"
+#define VERSION "6.0.6s2"
 #define DEBUG 1
-#define HOST_HEADER_VERSION "2.2.19-2cucs"
+#define HOST_HEADER_VERSION "2.4.0-0.26"
 #define YYTEXT_POINTER 1
 #define HAVE_LIBRPCSVC 1
 #define HAVE_LIBNSL 1
 #define HAVE_LIBLDAP 1
+#define HAVE_LIBRT 1
 #define HAVE_LIBGDBM 1
 #define HAVE_ALLOCA_H 1
 #define HAVE_ALLOCA 1
@@ -29,6 +30,7 @@
 #define HAVE_BZERO 1
 #define HAVE_CLNT_CREATE 1
 #define HAVE_CLNT_SPCREATEERROR 1
+#define HAVE_CLOCK_GETTIME 1
 #define HAVE_FLOCK 1
 #define HAVE_GET_MYADDRESS 1
 #define HAVE_GETCWD 1
@@ -126,7 +128,6 @@
 #define HAVE_ARPA_INET_H 1
 #define HAVE_DB1_NDBM_H 1
 #define HAVE_LINUX_AUTO_FS_H 1
-#define HAVE_LINUX_FS_H 1
 #define HAVE_LINUX_KDEV_T_H 1
 #define HAVE_LINUX_LIST_H 1
 #define HAVE_LINUX_NFS_H 1
@@ -177,7 +178,6 @@
 #define HAVE_MALLOC_H 1
 #define HAVE_MEMORY_H 1
 #define HAVE_MNTENT_H 1
-#define HAVE_NDBM_H 1
 #define HAVE_NETDB_H 1
 #define HAVE_PWD_H 1
 #define HAVE_REGEX_H 1
@@ -246,20 +246,27 @@
 #define HAVE_FIELD_NFS_ARGS_T_VERSION 1
 #define HAVE_FIELD_STRUCT_IFREQ_IFR_ADDR 1
 #define HAVE_FIELD_UMNTREQUEST_RDEVID 1
+#define HAVE_FGETS 1
 #define HAVE_MAP_FILE 1
+#define HAVE_LDAP_OPEN 1
 #define HAVE_MAP_LDAP 1
+#define HAVE_DBM_OPEN 1
 #define HAVE_MAP_NDBM 1
+#define HAVE_YP_GET_DEFAULT_DOMAIN 1
 #define HAVE_MAP_NIS 1
+#define HAVE_NIS_DOMAIN_OF 1
 #define HAVE_MAP_NISPLUS 1
+#define HAVE_GETPWNAM 1
 #define HAVE_MAP_PASSWD 1
+#define HAVE_OPENDIR 1
 #define HAVE_MAP_UNION 1
 #define HAVE_FS_AUTOFS 1
 #define HAVE_FS_CDFS 1
+#define HAVE_FS_LOFS 1
 #define HAVE_FS_NFS 1
 #define HAVE_FS_NFS3 1
 #define HAVE_FS_PCFS 1
 #define HAVE_FS_UFS 1
-#define HAVE_FS_EFS 1
 #define HAVE_AMU_FS_AUTO 1
 #define HAVE_AMU_FS_DIRECT 1
 #define HAVE_AMU_FS_TOPLVL 1
@@ -275,23 +282,24 @@
 #define MOUNT_TYPE_NFS MNTTYPE_NFS
 #define MOUNT_TYPE_NFS3 MNTTYPE_NFS3
 #define MOUNT_TYPE_UFS "ext2"
-#define MOUNT_TYPE_EFS "efs"
 #define MOUNT_TYPE_CDFS MNTTYPE_ISO9660
 #define MOUNT_TYPE_PCFS "vfat"
+#define MOUNT_TYPE_LOFS MNTTYPE_LOFS
 #define MOUNT_TYPE_AUTOFS "autofs"
 #define MOUNT_TYPE_IGNORE MNTTYPE_IGNORE
 #define MNTTAB_TYPE_NFS "nfs"
 #define MNTTAB_TYPE_NFS3 "nfs"
 #define MNTTAB_TYPE_UFS "ext2"
-#define MNTTAB_TYPE_EFS "efs"
 #define MNTTAB_TYPE_CDFS "iso9660"
 #define MNTTAB_TYPE_PCFS "vfat"
+#define MNTTAB_TYPE_LOFS "lofs"
 #define MNTTAB_TYPE_AUTOFS "autofs"
 #define MNTTAB_OPT_NOAUTO "noauto"
 #define MNTTAB_OPT_NOSUID "nosuid"
 #define MNTTAB_OPT_RO "ro"
 #define MNTTAB_OPT_RW "rw"
 #define MNTTAB_OPT_SUID "suid"
+#define MNT2_GEN_OPT_BIND 0x1000
 #define MNT2_GEN_OPT_NODEV 0x4
 #define MNT2_GEN_OPT_NOEXEC 0x8
 #define MNT2_GEN_OPT_NOSUID 0x2
